<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Channelstream Admin</title>
    <base href="{{ request.route_url('index')[:-1] }}"/>

    <script>
        var AppConf = {
            urls: {
                baseUrl: '{{ request.route_url('index')[:-1] }}',
                jsonUrl: '{{ request.route_url('admin_json') }}'
            }
        }

        window.process = {
            env: {
                NODE_ENV: 'production'
            }
        };

    </script>

    <script src="{{ request.static_url('channelstream:static/webcomponentsjs/custom-elements-es5-adapter.js') }}"></script>
    <script src="{{ request.static_url('channelstream:static/webcomponentsjs/webcomponents-loader.js') }}"></script>
    <script src="{{ request.static_url('channelstream:static/channelstream-admin.js') }}"></script>

</head>
<body>

<style>
    body {
        padding: 0;
        margin: 0;
        font-family: sans-serif;
    }

    h1 {
        margin: 0;
        padding: 20px;
        background-color: #3f51b5;
        color: #ffffff;
    }

    .container{
        padding: 20px;
    }

</style>

<h1>Channelstream Admin</h1>

<div class="container">
<channelstream-admin></channelstream-admin>
</div>
</body>
</html>
